@@ -6,6 +6,7 @@ import typing as tp
 from django.db import models
 
 from ._decorator import BACKEND_LINKER
+from ._decorator import django_model
 from ._protocols import T
 
 
@@ -13,43 +14,50 @@ from ._protocols import T
 class DjangoStore:
     identifier: str
 
-    def dump(self, dc_obj: tp.Any) -> models.Model:
-        django_model: type[models.Model] = BACKEND_LINKER.backend_class(dc_obj)
+    def dump(self, dc_obj: tp.Any) -> tuple[models.Model, bool]:
+        model = django_model(dc_obj)
         kwgs, m2m = self.dataclass_to_django(dc_obj)
-        dj_obj, created = django_model.objects.using(self.identifier).update_or_create(
-            **kwgs
-        )
+        dj_obj, created = model.objects.using(self.identifier).update_or_create(**kwgs)
 
         for key, vals in m2m.items():
             # remove old ones
             if not created:
                 getattr(dj_obj, key).clear()
             for val in vals:
-                getattr(dj_obj, key).add(self.dump(val))
+                sub_dj_obj, _ = self.dump(val)
+                getattr(dj_obj, key).add(sub_dj_obj)
 
-        return dj_obj  # type: ignore
+        return dj_obj, created
 
     def load(self, dataclass: type[T], **filter_kwgs: tp.Any) -> T:
-        django_model: type[models.Model] = BACKEND_LINKER.backend_class(dataclass)
-        instance = (
-            django_model.objects.using(self.identifier).filter(**filter_kwgs).first()
-        )
+        model = django_model(dataclass)
+        instance = self.django_load(model, **filter_kwgs)
         return self.django_to_dataclass(instance)  # type: ignore
 
-    def dataclass_to_django(self, dc_obj: models.Model) -> tp.Any:
-        django_model: type[models.Model] = BACKEND_LINKER.backend_class(dc_obj)
+    def django_load(
+        self, model: type[models.Model], **filter_kwgs: tp.Any
+    ) -> models.Model:
+        hits = model.objects.using(self.identifier).filter(**filter_kwgs).all()
+        if len(hits) > 1:
+            raise RuntimeError(
+                f"found {len(hits)} entries matching filter_kwgs {filter_kwgs}, be more specific!"
+            )
+        return hits[0]  # type: ignore
+
+    def dataclass_to_django(self, dc_obj: tp.Any) -> tp.Any:
+        model = django_model(dc_obj)
         kwgs = {}
         m2m = {}
         for field in dc.fields(dc_obj):
             key = field.name
             val = getattr(dc_obj, key)
             if type(val) in BACKEND_LINKER.dc_to_backend:
-                val = self.dump(val)
+                val, _ = self.dump(val)
             if isinstance(val, enum.Enum):
                 val = val.value
 
             # pylint: disable=protected-access
-            dj_model = django_model._meta.get_field(key)
+            dj_model = model._meta.get_field(key)
             if isinstance(dj_model, models.ManyToManyField):
                 m2m[key] = val
             else:
