@@ -4,7 +4,7 @@ import typing as tp
 T = tp.TypeVar("T")  # pylint: disable=invalid-name
 
 
-class StoreProtocol(tp.Protocol):
+class BackendStoreProtocol(tp.Protocol):
     def dump(self, obj: T) -> tp.Any:
         pass  # pragma: no cover
 
