@@ -12,11 +12,13 @@ from django.db import connections
 
 from ._decorator import BACKEND_LINKER
 from ._django_store import DjangoStore
-from ._protocols import StoreProtocol
+from ._protocols import BackendStoreProtocol
 
 __all__ = ["set_store", "set_store_for_django", "ACTIVE_STORES"]
 
-ACTIVE_STORES: collections.OrderedDict[str, StoreProtocol] = collections.OrderedDict()
+ACTIVE_STORES: collections.OrderedDict[
+    str, BackendStoreProtocol
+] = collections.OrderedDict()
 
 
 def set_store(
@@ -45,17 +47,21 @@ def set_store(
     else:
         raise NotImplementedError(flavor)
 
-    apps.apps_ready = apps.models_ready = apps.loading = apps.ready = False
-    apps.clear_cache()
+    new_apps = set(BACKEND_LINKER.app_labels) - set(settings.INSTALLED_APPS)
+
+    if not new_apps:
+        return
     for app_label in BACKEND_LINKER.app_labels:
-        if app_label not in settings.INSTALLED_APPS:
+        if app_label in new_apps:
             settings.INSTALLED_APPS.append(app_label)
 
+    apps.apps_ready = apps.models_ready = apps.loading = apps.ready = False
+    apps.clear_cache()
     apps.populate(settings.INSTALLED_APPS)
     connections.configure_settings(databases)
 
-    call_command("makemigrations")
     with contextlib.redirect_stdout(io.StringIO()):
+        call_command("makemigrations")
         call_command("migrate", database=identifier)
 
 
